@@ -3,12 +3,10 @@ fn main() {
 }
 
 #[cfg(any(feature = "embed-lgpl-docs", feature = "purge-lgpl-docs"))]
-fn manage_docs () {
+fn manage_docs() {
     extern crate lgpl_docs;
     const PATH: &'static str = "src";
-    const IGNORES: &'static [&'static str] = &[
-        "lib.rs",
-    ];
+    const IGNORES: &'static [&'static str] = &["lib.rs", "prelude.rs"];
     lgpl_docs::purge(PATH, IGNORES);
     if cfg!(feature = "embed-lgpl-docs") {
         lgpl_docs::embed(lgpl_docs::Library::Gio, PATH, IGNORES);
@@ -16,4 +14,4 @@ fn manage_docs () {
 }
 
 #[cfg(not(any(feature = "embed-lgpl-docs", feature = "purge-lgpl-docs")))]
-fn manage_docs() { }
+fn manage_docs() {}
