@@ -2,8 +2,7 @@
 // See the COPYRIGHT file at the top-level directory of this distribution.
 // Licensed under the MIT license, see the LICENSE file or <http://opensource.org/licenses/MIT>
 
-
-#[cfg(all(test,any(feature = "v2_36", feature = "dox")))]
+#[cfg(test)]
 mod tests {
     use *;
 
@@ -12,7 +11,7 @@ mod tests {
         let strm = MemoryOutputStream::new_resizable();
         assert_eq!(strm.get_data_size(), 0);
 
-        assert!(strm.close(None).is_ok());
+        assert!(strm.close(::NONE_CANCELLABLE).is_ok());
         assert_eq!(strm.steal_as_bytes().unwrap(), [].as_ref());
     }
 
@@ -20,13 +19,13 @@ mod tests {
     fn steal() {
         let strm = MemoryOutputStream::new_resizable();
 
-        assert!(strm.write(&[1, 2, 3], None).is_ok());
+        assert!(strm.write(&[1, 2, 3], ::NONE_CANCELLABLE).is_ok());
         assert_eq!(strm.get_data_size(), 3);
 
-        assert!(strm.write(&[4, 5], None).is_ok());
+        assert!(strm.write(&[4, 5], ::NONE_CANCELLABLE).is_ok());
         assert_eq!(strm.get_data_size(), 5);
 
-        assert!(strm.close(None).is_ok());
+        assert!(strm.close(::NONE_CANCELLABLE).is_ok());
         assert_eq!(strm.steal_as_bytes().unwrap(), [1, 2, 3, 4, 5].as_ref());
     }
 }
